package net.digitie.hibernate.blog;

import java.sql.Timestamp;
import java.util.Collections;
import java.util.Set;

import net.digitie.hibernate.blog.enum.CommentStatus;
import net.digitie.hibernate.blog.enum.PingStatus;
import net.digitie.hibernate.blog.enum.PostStatus;

/**
 * @author digitie
 * @hibernate.class 
 * 		table = "hawky_blog_post"
 * 		dynamic-update = "true"
 */
public class BlogPost {
    private long postId;
    private int memberId;
    private short postCat;
    private String nickName;
    private Timestamp regDate;
    private Timestamp modDate;
    private PostStatus postStatus;
    private CommentStatus commentStatus;
    private PingStatus pingStatus;
    private int comments;
    private int hit;
    private String title;
    private String content;
    private String excerpt;
    private String pinged;
    private String toPing;
    private String ipAddress;
    private Set BlogComment = Collections.EMPTY_SET;

    /**
     * @return 코멘트 갯수
     * @hibernate.property 
     * 		column = "comments" 
     * 		not-null = "true"
     */
    public final int getComments() {
        return comments;
    }

    /**
     * @param comments 코멘트 갯수
     */
    public final void setComments(int comments) {
        this.comments = comments;
    }

    /**
     * 코맨트 상태를 리턴하는 함수
     * 
     * @return 코맨트 상태
     * @hibernate.property 
     * 		column = "comment_status" 
     * 		not-null = "true"
     * 		type = "net.digitie.hibernate.blog.enum.CommentStatus"
     */
    public final CommentStatus getCommentStatus() {
        return commentStatus;
    }

    /**
     * @param commentStatus 코맨트 상태
     */
    public final void setCommentStatus(CommentStatus commentStatus) {
        this.commentStatus = commentStatus;
    }

    /**
     * @return 내용
     * @hibernate.property 
     * 		column = "content" 
     * 		not-null = "true"
     */
    public final String getContent() {
        return content;
    }

    /**
     * @param content 내용
     */
    public final void setContent(String content) {
        this.content = content;
    }

    /**
     * 내용 요약을 적지 않으면 내용(@see #content)에서 255자를 잘라내어 입력한다. 255자가 넘어가면 252자가 남고
     * <code>...</code> 이 붙는다.
     * 
     * @return 트랙백에 필요한 내용 요약 TODO PostgreSQL의 트리거 점검후 not-null에 대한 수정 필요
     * @hibernate.property 
     * 		column = "excerpt" 
     * 		not-null = "true"
     */
    public final String getExcerpt() {
        return excerpt;
    }

    /**
     * @param excerpt 트랙백에 필요한 내용 요약
     */
    public final void setExcerpt(String excerpt) {
        this.excerpt = excerpt;
    }

    /**
     * @return 맴버 고유 번호
     * @see net.digitie.hibernate.member.Member#memberId
     * @hibernate.many-to-one 
     * 		class = "Member"
     * 		column = "member_id" 
     * 		not-null = "true"
     */
    public final int getMemberId() {
        return memberId;
    }

    /**
     * @param memberId 맴버 고유 번호
     */
    public final void setMemberId(int memberId) {
        this.memberId = memberId;
    }

    /**
     * 블로그를 작성할때는 수정시각과 생성시각이 같은 값을 가진다. TODO 트리거 작성
     * 
     * @return 수정 시각
     * @hibernate.property 
     * 		column = "mod_date" 
     * 		not-null = "true"
     */
    public final Timestamp getModDate() {
        return modDate;
    }

    /**
     * @param modDate 수정 시각
     */
    public final void setModDate(Timestamp modDate) {
        this.modDate = modDate;
    }

    /**
     * @return Returns the pinged.
     * @hibernate.property 
     * 		column = "pinged"
     */
    public final String getPinged() {
        return pinged;
    }

    /**
     * @param pinged The pinged to set.
     */
    public final void setPinged(String pinged) {
        this.pinged = pinged;
    }

    /**
     * @return 블로그 카테고리
     * @hibernate.many-to-one 
     * 		class = "BlogCategory"
     * 		column = "post_cat" 
     * 		not-null = "true"
     */
    public final short getPostCat() {
        return postCat;
    }

    /**
     * @param postCat 블로그 카테고리
     */
    public final void setPostCat(short postCat) {
        this.postCat = postCat;
    }

    /**
     * @return 블로그 포스트 고유 번호
     * @hibernate.id 
     * 		column = "post_id" 
     * 		generator-class = "native"
     */
    public final long getPostId() {
        return postId;
    }

    /**
     * @param postId 블로그 포스트 고유 번호
     */
    public final void setPostId(long postId) {
        this.postId = postId;
    }

    /**
     * @return 등록한 블로그 상태
     * @hibernate.property 
     * 		column = "post_status" 
     * 		not-null = "true"
     * 		type = "net.digitie.hibernate.blog.enum.PostStatus"
     */
    public final PostStatus getPostStatus() {
        return postStatus;
    }

    /**
     * @param postStatus 등록한 블로그 상태
     */
    public final void setPostStatus(PostStatus postStatus) {
        this.postStatus = postStatus;
    }

    /**
     * @return 블로그 등록 시간 
     * @hibernate.property 
     * 		column = "reg_date" 
     * 		not-null = "true"
     */
    public final Timestamp getRegDate() {
        return regDate;
    }

    /**
     * @param regDate 블로그 등록 시간
     */
    public final void setRegDate(Timestamp regDate) {
        this.regDate = regDate;
    }

    /**
     * @return 블로그 제목
     * @hibernate.property 
     * 		column = "title" 
     * 		not-null = "true"
     */
    public final String getTitle() {
        return title;
    }

    /**
     * @param title 블로그 제목
     */
    public final void setTitle(String title) {
        this.title = title;
    }

    /**
     * @return Returns the hit.
     * @hibernate.property 
     * 		column = "hit"
     * 		not-null = "true"
     */
    public final int getHit() {
        return hit;
    }
    /**
     * @param hit The hit to set.
     */
    public final void setHit(int hit) {
        this.hit = hit;
    }
    /**
     * @return Returns the toPing. 
     * @hibernate.property 
     * 		column = "to_ping" 
     * 		not-null = "true"
     */
    public final String getToPing() {
        return toPing;
    }

    /**
     * @param toPing The toPing to set.
     */
    public final void setToPing(String toPing) {
        this.toPing = toPing;
    }
    /**
     * @return Returns the blogComment.
     * @hibernate.set 
     * 		cascade = "all" 
     * 		lazy = "true" 
     * 		inverse = "true"
     * @hibernate.collection-key 
     * 		column = "post_id"
     * @hibernate.collection-one-to-many 
     * 		class = "BlogComment"
     */
    public final Set getBlogComment() {
        return BlogComment;
    }
    /**
     * @param blogComment 이 블로그에 대한 코멘트 리스트
     */
    public final void setBlogComment(Set blogComment) {
        BlogComment = blogComment;
    }
    /**
     * @return 글쓴이의 아이피
     * @hibernate.property 
     * 		column = "ip_address"
     * 		not-null = "true"
     */
    public final String getIpAddress() {
        return ipAddress;
    }
    /**
     * @param ipAddress 글쓴이의 아이피
     */
    public final void setIpAddress(String ipAddress) {
        this.ipAddress = ipAddress;
    }
    /**
     * @return 닉네임
     * TODO postgresql not-null 관련 트리거 동작 여부 확인
     * @hibernate.property 
     * 		column = "nick_name"
     * 		not-null = "true"
     */
    public final String getNickName() {
        return nickName;
    }
    /**
     * 닉네임을 입력하지 않을 경우 member에 있는 nick이 입력된다.
     * @param nickName 닉네임
     */
    public final void setNickName(String nickName) {
        this.nickName = nickName;
    }
    /**
     * @return Returns the pingStatus.
     * @hibernate.property 
     * 		column = "ping_status"
     * 		not-null = "true"
     * 		type = "net.digitie.hibernate.blog.enum.PingStatus"
     */
    public final PingStatus getPingStatus() {
        return pingStatus;
    }
    /**
     * @param pingStatus The pingStatus to set.
     */
    public final void setPingStatus(PingStatus pingStatus) {
        this.pingStatus = pingStatus;
    }
}